summaryrefslogtreecommitdiff
path: root/odb/common.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'odb/common.cxx')
-rw-r--r--odb/common.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/odb/common.cxx b/odb/common.cxx
index f52cee6..b75d323 100644
--- a/odb/common.cxx
+++ b/odb/common.cxx
@@ -504,9 +504,9 @@ check (semantics::typedefs& t)
if (ci == 0)
return false;
// It must be a composite value.
//
- if (!composite (*ci))
+ if (!object (*ci) && !composite (*ci))
return false;
// This typedef name should be the one that was used in the pragma.
@@ -504,9 +504,9 @@ check (semantics::typedefs& t)
if (ci == 0)
return false;
- // It must be a composite value.
+ // It must be an object or composite value.
//